Infer an Item From a Nortek AD2CP File Header
ad2cpHeaderValue(x, key, item, numeric = TRUE, default, plan = 0, debug = 0)ad2cpHeaderValue returns a character value or number interpreted
from the output from x[["text"]], or NULL, if the desired item is not
found there, or if x is not of the required class and variety.
an adp object that holds AD2CP data.
character value that identifies a particular line in the file header.
character value indicating the name of the item sought.
logical value indicating whether to convert the return value from a string to a numerical value.
optional value to be used if the item is not found in the
header, or if the header is NULL (as in the case of a split-up file
that lacks the initial header information)
integer specifying the plan, with the same
meaning as for read.adp.ad2cp().
integer indicating degree of debugging information to be printed during processing. The default value of 0 means to work quietly.
if (file.exists("a.ad2cp")) {
d <- read.oce("a.ad2cp")
# The examples start with the line in x[["text"]][[1]]; note that in the second
# example, it would be insuficient to use a key of "BEAMCFGLIST", because that will
# yield 4 lines, and the function is not designed to handle that.# ID,STR=\"Signature1000\",SN=123456 type <- ad2cpHeaderValue(d, "ID", "STR", numeric=FALSE) serialNumber <- ad2cpHeaderValue(d, "ID", "SN")
# BEAMCFGLIST,BEAM=1,THETA=25.00,PHI=0.00,FREQ=1000,BW=25,BRD=1,HWBEAM=1,ZNOM=60.00 beam1Angle <- ad2cpHeaderValue(d, "BEAMCFGLIST,BEAM=1", "THETA") frequency <- ad2cpHeaderValue(d, "BEAMCFGLIST,BEAM=1", "FREQ", default=NA) }
Dan Kelley
Other things related to adp data:
[[,adp-method,
[[<-,adp-method,
ad2cpCodeToName(),
adp,
adp-class,
adpAd2cpFileTrim(),
adpConvertRawToNumeric(),
adpEnsembleAverage(),
adpFlagPastBoundary(),
adpRdiFileTrim(),
adp_rdi.000,
applyMagneticDeclination,adp-method,
as.adp(),
beamName(),
beamToXyz(),
beamToXyzAdp(),
beamToXyzAdpAD2CP(),
beamToXyzAdv(),
beamUnspreadAdp(),
binmapAdp(),
enuToOther(),
enuToOtherAdp(),
handleFlags,adp-method,
is.ad2cp(),
plot,adp-method,
read.adp(),
read.adp.ad2cp(),
read.adp.nortek(),
read.adp.rdi(),
read.adp.sontek(),
read.adp.sontek.serial(),
read.aquadopp(),
read.aquadoppHR(),
read.aquadoppProfiler(),
rotateAboutZ(),
setFlags,adp-method,
subset,adp-method,
subtractBottomVelocity(),
summary,adp-method,
toEnu(),
toEnuAdp(),
velocityStatistics(),
xyzToEnu(),
xyzToEnuAdp(),
xyzToEnuAdpAD2CP()
Other things related to ad2cp data:
ad2cpCodeToName(),
adpAd2cpFileTrim(),
is.ad2cp(),
read.adp.ad2cp()