Convert a argo object into a ctd object. This
function may be called by as.ctd() or called directly. In the
first case, note that the only as.ctd() parameters that are
provided to the present function are the object itself,
the index number of the desired profile, and the debug
value.
argo2ctd(argo, profile = NULL, debug = getOption("oceDebug"))an argo object.
an integer specifying the profile to pick within the argo object. If this is not provided, it will be set to 1, and a warning will be issued telling of this setting.
an integer specifying whether debugging information is
to be printed during the processing. This is a general parameter that
is used by many oce functions. Generally, setting debug=0
turns off the printing, while higher values suggest that more information
be printed. If one function calls another, it usually reduces the value of
debug first, so that a user can often obtain deeper debugging
by specifying higher debug values.
Dan Kelley
The resultant ctd object has a constructed station name, made by
taking the filename stored within argo and appending an underscore
character, followed by the profile number. For example, if the filename for
argo is D6902967_001.nc and if the profile parameter is 1, then the
station number will be D6902967_001_1.
Other things related to argo data:
D4902337_219.nc,
[[,argo-method,
[[<-,argo-method,
argo,
argo-class,
argoGrid(),
argoNames2oceNames(),
as.argo(),
handleFlags,argo-method,
plot,argo-method,
read.argo(),
read.argo.copernicus(),
subset,argo-method,
summary,argo-method
Other things related to ctd data:
CTD_BCD2014666_008_1_DN.ODF.gz,
[[,ctd-method,
[[<-,ctd-method,
as.ctd(),
cnvName2oceName(),
ctd,
ctd-class,
ctd.cnv.gz,
ctdDecimate(),
ctdFindProfiles(),
ctdFindProfilesRBR(),
ctdRaw,
ctdRepair(),
ctdTrim(),
ctd_aml_type1.csv.gz,
ctd_aml_type3.csv.gz,
d200321-001.ctd.gz,
d201211_0011.cnv.gz,
handleFlags,ctd-method,
initialize,ctd-method,
initializeFlagScheme,ctd-method,
oceNames2whpNames(),
oceUnits2whpUnits(),
plot,ctd-method,
plotProfile(),
plotScan(),
plotTS(),
read.ctd(),
read.ctd.aml(),
read.ctd.itp(),
read.ctd.odf(),
read.ctd.odv(),
read.ctd.saiv(),
read.ctd.sbe(),
read.ctd.ssda(),
read.ctd.woce(),
read.ctd.woce.other(),
setFlags,ctd-method,
subset,ctd-method,
summary,ctd-method,
woceNames2oceNames(),
woceUnit2oceUnit(),
write.ctd()
# Read a built-in Argo dataset and convert to a CTD object
# for plotting.
library(oce)
argo <- read.argo(system.file("extdata", "D4902337_219.nc", package = "oce"))
ctd <- as.ctd(argo) # warns of a default 'profile' choice
plot(ctd)
Run the code above in your browser using DataLab