as.gps(longitude, latitude, filename="")latitude and
longitude, in which case these values are extracted from the data
frame and the second argument is igread.gps cannot read a file, or
when the data have been manipulated.gps-class explains the
structure of gps objects, and also outlines the other functions
dealing with them.