Learn R Programming

oce (version 0.1.63)

coastline: Sample coastline data set

Description

A sample coastline dataset, showing Nova Scotia, Prince Edward Island, and part of New Brunswick. This is the oce author's stomping ground, and so he feels compelled to apologize for the error at the Strait of Canso.

Usage

data(coastline)

Arguments

source

The data were extracted from the NOAA site, specifying the Splus data type, and read with read.coastline.

References

http://www.ngdc.noaa.gov/mgg_coastline/

See Also

read.coastline