Concatenate a List of oce Objects
# S4 method for list
concatenate(object, debug = getOption("oceDebug"))An object of class corresponding to that in the elements of object.
a list of oce objects, all of which must have the same sub-class (e.g. all of ctd, or adp, etc).
a debugging flag, set to a positive value to get debugging. Note
that debug-1 is passed to the other concatenate() functions that are
called by the present function.
Other functions for concatenating oce objects:
concatenate(),
concatenate,adp-method