Learn R Programming

oce (version 0.1.63)

read.coastline: Scan a coastline data file

Description

Read a coastline file in mapgen, matlab, or Splus format

Usage

read.coastline(file,type=c("R","S","mapgen"),debug=FALSE)

Arguments

file
Name of file containing coastline data.
type
Type of file, one of "R", "S", or "mapgen"
debug
Set to TRUE to print information about the header, etc.

Value

  • A coastline object containing
  • processing.logA processing log.
  • latNorth latitude, in decimal degrees.
  • lonEast longitude, in decimal degrees.

Details

The S and R formats are identical, and consist of two columns, lon and lat, with land-jump segments separated by lines with two NAs.

The MapGen format is of the form # -b -16.179081 28.553943 -16.244793 28.563330 BUG: the 'arc/info ungenerate' format is not yet understood.

References

http://www.ngdc.noaa.gov/mgg/shorelines/shorelines.html

See Also

plot.coastline summary.coastline

Examples

Run this code
library(oce)
cl <- read.coastline("7404.dat")
# If no plot yet:
plot(cl)
# To add to an existing plot:
lines(cl$lon, cl$lat)
# Note: another trick is to do something like the following,
# to get issues of whether longitude is defined in (-180,180)
# or (0,360)
lines(cl$lon, cl$lat)
lines(cl$lon_360, cl$lat)

Run the code above in your browser using DataLab