Learn R Programming

oce (version 1.8-4)

section: Sample section Data

Description

This is from a 1993 occupation of WOCE line A03 that ran westward across the Atlantic at approximately 36 N, ending with a turn to the northwest in the Gulf Stream region.

Usage

data(section)

Arguments

Details

The sampling times in this dataset are not fully sequential. For example, Station 41 is reported to be at 1993-10-03T00:06:00, which, going by station numbers, suggests an error in the reported day. Station 45 seems to have a similar problem. However, the goal here is to represent the data as archived, so no changes are made to the times.

See Also

Other datasets provided with oce: adp, adv, amsr, argo, cm, coastlineWorld, ctd, ctdRaw, echosounder, landsat, lisst, lobo, met, ocecolors, rsk, sealevel, sealevelTuktoyaktuk, topoWorld, wind, xbt

Other things related to section data: [[,section-method, [[<-,section-method, as.section(), handleFlags,section-method, initializeFlagScheme,section-method, plot,section-method, read.section(), section-class, sectionAddStation(), sectionGrid(), sectionSmooth(), sectionSort(), subset,section-method, summary,section-method

Examples

Run this code
library(oce)
# Gulf Stream
data(section)
GS <- subset(section, 113 <= stationId & stationId <= 129)
GSg <- sectionGrid(GS, p = seq(0, 5000, 100))
plot(GSg, span = 1500) # increase span to show more coastline

Run the code above in your browser using DataLab