Learn R Programming

oce (version 1.4-0)

summary,tidem-method: Summarize a Tidem Object

Description

By default, all fitted constituents are plotted, but it is quite useful to set e.g. p=0.05 To see just those constituents that are significant at the 5 percent level. Note that the p values are estimated as the average of the p values for the sine and cosine components at a given frequency.

Usage

# S4 method for tidem
summary(object, p, constituent, ...)

Arguments

object

an object of class tidem, as created by as.tidem() or tidem().

p

optional value of the maximum p value for the display of an individual coefficient. If not given, all coefficients are shown.

constituent

optional character vector holding the names of constituents on which to focus.

…

further arguments passed to or from other methods.

Value

NULL

See Also

Other things related to tides: [[,tidem-method, [[<-,tidem-method, as.tidem(), plot,tidem-method, predict.tidem(), tidalCurrent, tidedata, tidem-class, tidemAstron(), tidemVuf(), tidem, webtide()

Examples

Run this code
# NOT RUN {
library(oce)
data(sealevel)
tide <- tidem(sealevel)
summary(tide)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab