landsat object.## S3 method for class 'landsat}(object, \dots)':
summaryundefined- object
{an object of class "landsat", usually, a result of a
call to read.landsat.}
- ...
{further arguments passed to or from other methods.}
Pertinent summary information is presented, including the station
name, sampling location, data ranges, etc.
An object of class "summary.landsat", which when printed shows
pertinent information about the landsat record and its processing.
The documentation for landsat-class explains the
structure of landsat objects, and also outlines the other functions dealing
with them.
[object Object]
misc