sw.S.T.rho: Seawater salinity from temperature and density
Description
Compute in-situ salinity, given temperature, density, and pressure.
Usage
S <- sw.S.T.rho(t, sig, p);
Arguments
t
in-situ temperature [$^\circ$C]
sig
in-situ density or sigma value [$kg/m^3$]
p
in-situ pressure [dbar]
Value
In-situ salinity [PSU].
Details
Finds the salinity that yields the given density, with the given temperature and pressure.
The method is a bisection search with a salinity tolerance of
0.001. The isopycnal lines on
temperature-salinity diagrams (plot.TS) are computed with this function.
References
Fofonoff, P. and R. C. Millard Jr, 1983. Algorithms for computation of
fundamental properties of seawater. Unesco Technical Papers in Marine
Science, 44, 53 pp
Gill, A.E., 1982. Atmosphere-ocean Dynamics,
Academic Press, New York, 662 pp.