sw.T.S.rho: Seawater temperature from salinity and density
Description
Compute in-situ temperature, given salinity, density, and pressure.
Usage
temperature <- sw.T.S.rho(S, sig, p);
Arguments
S
in-situ salinity [PSU]
sig
in-situ density or sigma value [$kg/m^3$]
p
in-situ pressure [dbar]
Value
In-situ temperature [$^\circ C$].
Details
Finds the temperature that yields the given density, with the given salinity and pressure.
The method is a bisection search with temperature tolerance 0.001 $^\circ C$.
References
Fofonoff, P. and R. C. Millard Jr, 1983. Algorithms for computation of
fundamental properties of seawater. Unesco Technical Papers in Marine
Science, 44, 53 pp
Gill, A.E., 1982. Atmosphere-ocean Dynamics,
Academic Press, New York, 662 pp.