Learn R Programming

oce (version 0.1.63)

sw.rho: Seawater density

Description

Compute, $\rho$, the in-situ density of seawater.

Usage

rho <- sw.rho(S, t, p);

Arguments

S
in-situ salinity [PSU]
t
in-situ temperature [$^\circ$C]
p
in-situ pressure [dbar]

Value

  • In-situ density [kg/m$^3$].

Details

The density is calculated using the UNESCO equation of state for seawater, assuming that input variables are defined according to modern calibrations. In conventional Oceanographic notation, the calculated quantity is $\rho(S,t,p)$

References

Fofonoff, P. and R. C. Millard Jr, 1983. Algorithms for computation of fundamental properties of seawater. Unesco Technical Papers in Marine Science, 44, 53 pp

Gill, A.E., 1982. Atmosphere-ocean Dynamics, Academic Press, New York, 662 pp.

See Also

N/A.

Examples

Run this code
rho <- sw.rho(35, 13, 1000) # 1030.818

Run the code above in your browser using DataLab