Learn R Programming

oce (version 0.1.69)

sw.sigma: Seawater density anomaly

Description

Compute $\sigma$, the in-situ density of seawater, minus 1000 kg/m$^3$.

Usage

sig <- sw.sigma(S, t, p);

Arguments

S
in-situ salinity [PSU]
t
in-situ temperature [$^\circ$C]
p
in-situ pressure [dbar]

Value

  • In-situ density anomaly [kg/m$^3$].

Details

Definition: $\rho(S,t,p)$ - 1000 kg/m$^3$.

References

Fofonoff, P. and R. C. Millard Jr, 1983. Algorithms for computation of fundamental properties of seawater. Unesco Technical Papers in Marine Science, 44, 53 pp

Gill, A.E., 1982. Atmosphere-ocean Dynamics, Academic Press, New York, 662 pp.

See Also

Related density routines include: sw.rho to calculate in-situ density, sw.sigma.t to calculate an archaic quantity found in old textbooks, and sw.sigma.theta to calculate potential density anomaly relative to the surface pressure. If you are thinking of using sw.sigma, you probably want sw.sigma.theta.

Examples

Run this code
sig <- sw.sigma(35, 13, 1000)	# 30.818

Run the code above in your browser using DataLab