Skip to contents

This is used by read.rsk() to infer the units of data, based on strings stored in .rsk files. Lacking a definitive guide to the format of these file, this function was based on visual inspection of the data contained within a few sample files; unusual sensors may not be handled properly.

Usage

unitFromStringRsk(s)

Arguments

s

Vector of character strings, holding the units entry in the channels table of the .rsk database.

Value

List of unit lists.

See also