as.argo(time, longitude, latitude, salinity, temperature, pressure,
units=NULL, id, filename="", missingValue)NULL, the default,
then "degree east" is used for longitude,
"degree north" for latitude,
"" for salinity,
NA.class "argo".argo-class object,
e.g. so that plot.argo can be used. Use oceSetData
to add other columns to the standard set, if e.g. the device measures
nitrate, etc.argo-class explains the structure
of argo objects, and also outlines the other functions dealing with them.