Rdocumentation
powered by
Learn R Programming
oce (version 0.1.67)
as.coastline: Coerce data into coastline dataset
Description
Coerces a sequence of latitudes and longitudes into a coastline dataset.
Usage
as.coastline(latitude, longitude)
Arguments
latitude
the latitude in decimal degrees, positive north of the equator.
longitude
the longitude in decimal degrees, positive north of Greenwich.
Value
A
coastline
object.
Details
This may be used when
read.coastline
cannot read a file, or when the data have been manipulated.
See Also
read.coastline
reads data
plot.coastline
plots it.