as.rsk(time, columns,
filename="", instrumentType="rbr", serialNumber="", model="",
sampleInterval=NA,
debug=getOption("oceDebug"))"RBRduo"NA, then this
is estimated as the median difference in times.TRUE to turn on debugging.class "rsk".columns are be copied into the data slot
of the returned object directly, so it is critical that the names and units
correspond to those expected by other code dealing with
rsk-class objects. If there is a conductivity, it must be called
conductivity, and it must be in units of mS/cm. If there is a
temperature, it must be called temperature, and it must be an in-situ
value recorded in ITS-90 units. And if there is a pressure, it must be
absolute pressure (sea pressure plus atmospheric pressure) and it must
be named pressure. No checks are made within as.rsk on any of
these rules, but if they are broken, you may expect problems with any further
processing.rsk-class explains the structure of
rsk objects, and also outlines the other functions dealing with them.