Learn R Programming

oce (version 0.1.67)

as.sealevel: Coerce data into sea-level dataset

Description

Coerces a dataset (minimally, a sequence of heights) into a sealevel dataset.

Usage

as.sealevel(t=NULL,
  eta=NULL,
  header=NULL,
  station.number=NA,
  station.version=NA,
  station.name=NULL,
  region=NA,
  year=NA,
  latitude=NA,
  longitude=NA,
  GMT.offset=NA,
  decimation.method=NA,
  reference.offset=NA,
  reference.code=NA,
  processing.log=NULL)

Arguments

t
a list of times, in POSIXct format.
eta
a list of sea-level heights in metres, in an hourly sequence.
header
a character string as read from first line of a standard data file.
station.number
three-character string giving station number.
station.version
single character for version of station.
station.name
the name of station (at most 18 characters).
region
the name of the region or country of station (at most 19 characters).
year
the year of observation.
latitude
the latitude in decimal degrees, positive north of the equator.
longitude
the longitude in decimal degrees, positive east of Greenwich.
GMT.offset
offset from GMT. (BUG: this is ignored.)
decimation.method
a coded value, with 1 meaning filtered, 2 meaning a simple average of all samples, 3 meaning spot readings, and 4 meaning some other method.
reference.offset
?
reference.code
?
processing.log
a processing log

Value

  • A sealevel object.

Details

The arguments are based on the standard data format, as described at ftp://ilikai.soest.hawaii.edu/rqds/hourly.fmt.

References

ftp://ilikai.soest.hawaii.edu/rqds/hourly.fmt.

See Also

read.sealevel reads data, summary.sealevel summarizes the information, while plot.sealevel plots it.

Examples

Run this code
library(oce)
h <- 0:(24*100) # 100 days after 911
t <- as.POSIXct("2001-09-11") + h * 3600
eta <- 1.0 * sin(2*pi*h/12.4172) + 0.8 * sin(2*pi*h/24.0)
eta <- eta + 0.1 * rnorm(length(h)) # add some noise
sl <- as.sealevel(t, eta)
summary(sl)

Run the code above in your browser using DataLab