Usage
as.sealevel(t=NULL,
eta=NULL,
header=NULL,
station.number=NA,
station.version=NA,
station.name=NULL,
region=NA,
year=NA,
latitude=NA,
longitude=NA,
GMT.offset=NA,
decimation.method=NA,
reference.offset=NA,
reference.code=NA,
processing.log=NULL)
Arguments
t
a list of times, in POSIXct format.
eta
a list of sea-level heights in metres, in an hourly sequence.
header
a character string as read from first line of a standard data file.
station.number
three-character string giving station number.
station.version
single character for version of station.
station.name
the name of station (at most 18 characters).
region
the name of the region or country of station (at most 19 characters).
year
the year of observation.
latitude
the latitude in decimal degrees, positive north of the equator.
longitude
the longitude in decimal degrees, positive east of Greenwich.
GMT.offset
offset from GMT. (BUG: this is ignored.)
decimation.method
a coded value, with 1 meaning filtered, 2 meaning a simple average of all samples, 3 meaning spot readings, and 4 meaning some other method.
processing.log
a processing log