Solution of the geodetic inverse problem after T.Vincenty
modified Rainsford's method with Helmert's elliptical terms
effective in any azimuth and at any distance short of antipodal
standpoint/forepoint must not be the geographic pole. If the "1" and "2" lists are of equal length, then the result is
the pairwise distances. However, if the length of "2" is shorter
than the length of "1", then only the first value in the
"2" list is used, repeated over and over to match the length of
"1".
A common use is for "1" to contain a vector of positions
along a cruise track, and for "2" to contain a reference point;
e.g. geod.dist(lats,lons,lats[1],lons[1]) gives distance
along the track starting from zero.