lookWithin(list)swRho(ctd), in which the first argument, which is
normally salinity may be an object that contains salinity plus
the other items that swRho expects to see as arguments. This
shorthand is very helpful in calls to the suite of sw functions. If
this first argument is an object of this sort, then the other arguments
are ignored except for two special cases:
eos is copied directly from list
temperature defined with the IPTS-68
scale, then T90fromT68 is used to convert to the ITS-90 scale,
because this is what is expected in most seawater functions. (For example,
the RMS difference between these temperature variants is 0.002C for the
ctd dataset.)