axis.POSIXct but with axis labels obeying the timezone of
x. This will not be needed for 2.9 and later, but is included so
that oce will work even with earlier versions.
oce.axis.POSIXct(side, x, at, tformat, labels = TRUE, drawTimeRange = getOption("oceDrawTimeRange"), abbreviateTimeRange = FALSE, drawFrequency = FALSE, cex = par("cex"), cex.axis = par("cex.axis"), cex.main = par("cex.main"), mar = par("mar"), mgp = par("mgp"), main = "", debug = getOption("oceDebug"), ...)axis.POSIXct.axis.POSIXct.axis.POSIXct.format for axis.POSIXct for now, but
eventually will have new features for multiline labels, e.g. day on one line
and month on another.axis.POSIXct.TRUE to draw a time range on the
opposite side of the plot.TRUE to abbreviate the second
number in the time range, e.g. dropping the year if it is the same in the
first number.TRUE to show the frequency of sampling
in the datapar("cex").par("cex.axis").par("cex.main").par(mar) for axispar(mgp) for axisaxis.POSIXct.oce.plot.ts.