oceColorsCubeHelix: Create Colors in the Cube Helix Style
Description
This is a colour scheme that renders well in black and white,
that has colours that are reasonably distinct for many
viewers, and that may be good for persons with colour
deficiencies. For more on such matters, the underlying
theory, and the meanings of the parameter values, please
see Green (2011). That R code for the present function
is a rewriting of Fortran code provided in an appendix
of that paper.
library(oce)
# Example 1: normal (dark for low values)imagep(volcano, col = oceColorsCubeHelix)
# Example 2: reversed (dark for high values)imagep(volcano, col = \(n) rev(oceColorsCubeHelix(n)))