library(oce)
cl <- read.coastline("7404.dat")
# If no plot yet:
plot(cl)
# To add to an existing plot:
lines(cl$lon, cl$lat)
# Note: another trick is to do something like the following,
# to get issues of whether longitude is defined in (-180,180)
# or (0,360)
lines(cl$lon, cl$lat)
lines(cl$lon_360, cl$lat)Run the code above in your browser using DataLab