read.met(file, type = NULL, skip, tz = getOption("oceTz"), debug = getOption("oceDebug"), processingLog, ...)NULL, then the first line is studied, in order to
determine the file type. If type="msc", then a file as formatted by
the Meteorological Service of Canada is assumed.read.met scans the file until it
finds a line starting with "Date/Time", and considers all lines above
that to be header.class "met", of which the
data slot contains vectors time, temperature,
pressure, u, and v. The velocity components have units
m/s and are the components of the vector of wind direction. In other words,
the oceanographic convention on velocity is employed, not the meteorological
one; the weather forecaster's "North wind" has positive v and zero
u. In addition to these things, data also contains items
called wind (in km/h) and direction (in tenths of a degree),
taken straight from the data file.
met data: [[,met-method,
[[<-,met-method, as.met,
met-class, met,
plot,met-method,
subset,met-method,
summary,met-method
## Not run:
# library(oce)
# met <- read.met("ile-rouge-eng-hourly-06012008-06302008.csv")
# plot(met, which=3:4)
# ## End(Not run)
Run the code above in your browser using DataLab