read.sealevel(file, debug=FALSE)TRUE to get debugging information during processing.sealevel object containingt, times of observations and eta, the sealevel observations, in units units (normally, mm)as.sealevel to create the sealevel object.read.oce provides an alternative to this.
A sealevel object may be summarized with summary.sealevel and plotted with
plot.sealevel.A sealevel object can also be constructed with as.sealevel.
library(oce)
h <- read.sealevel("ftp://ilikai.soest.hawaii.edu/rqds/pacific/monthly/m652a.dat")
summary(h)
plot(h)Run the code above in your browser using DataLab