Learn R Programming

oce (version 0.1.63)

read.sealevel: Read a sea-level data file

Description

Read a data file holding sea level data. BUG: the time vector assumes GMT, regardless of the GMT.offset value.

Usage

read.sealevel(file,debug=FALSE)

Arguments

file
A connection or a character string giving the name of the file to load.
debug
Set to TRUE to get debugging information during processing.

Value

  • A sealevel object containing
  • headerThe header line (helpful if detail extraction failed)
  • ... for various station descriptors, see as.sealevel
  • nNumber of data values
  • hourTimes [h]
  • timeTime [POSIXct]
  • processing.logA processing log.
  • etaSea level [m]

Details

See sealevel for details of the data format.

References

The site http://ilikai.soest.hawaii.edu/uhslc/datai.html provides a graphical interface for downloading sealevel data.

See Also

summary.sealevel summarizes the information, while plot.sealevel plots it.

Examples

Run this code
library(oce)
h<-read.sealevel("ftp://ilikai.soest.hawaii.edu/rqds/pacific/monthly/m652a.dat")
summary(h)
plot(h)

Run the code above in your browser using DataLab