Learn R Programming

oce (version 0.1.69)

sealevel: Sample sea-level data set

Description

This sample sea-level dataset is the 2003 record from Halifax Harbour in Nova Scotia, Canada. Note that Hurricane Juan hit Halifax on September 28th of 2003, causing a strong storm surge.

Usage

data(sealevel)

Arguments

source

The data were downloaded from MEDS and then read with read.sealevel.

References

The MEDS archive is at http://www.meds-sdmm.dfo-mpo.gc.ca/meds/Databases/TWL/TWL_inventory_e.htm. An entry to the literature about Hurricane Juan is at http://www.atl.ec.gc.ca/weather/hurricane/juan/.