landsat object.## S3 method for class 'landsat':
summary(object, \dots)"landsat", usually, a result of a
call to read.landsat."summary.landsat", which when printed shows
pertinent information about the landsat record and its processing.landsat-class explains the
structure of landsat objects, and also outlines the other functions dealing
with them.