Compute seawater "spice" (a variable orthogonal to density in TS space)
Usage
spice <- sw.spice(S, t, p);
Arguments
S
in-situ salinity [PSU]
t
in-situ temperature [$^\circ$C]
p
in-situ pressure [dbar]
Value
Spice [kg/m$^3$].
Details
Roughly speaking, seawater with a high spiciness is relatively warm
and salty compared with less spicy water. Another interpretation is
that spice is a variable measuring distance orthogonal to isopycnal
lines on TS diagrams (if the diagrams are scaled to make the
isopycnals run at 45 degres). The definition used here is that of
Pierre Flament. (Other formulations exist.) Note that pressure is
ignored in the definition. Spiceness is sometimes denoted
$\pi(S,t,p)$.
References
P. Flament, 2002.
A state variable for characterizing water masses and their diffusive
stability: spiciness. Progr. Oceanog.,
54, 493-501.